(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('pdfjs-dist/build/pdf.combined'), require('pdfjs-dist/web/pdf_viewer'), require('@angular/common')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', 'pdfjs-dist/build/pdf.combined', 'pdfjs-dist/web/pdf_viewer', '@angular/common'], factory) :
	(factory((global.angularPdfViewer = {}),global.ng.core,null,null,global.ng.common));
}(this, (function (exports,core,pdf_combined,pdf_viewer,common) { 'use strict';

/**
 *
 * RenderingQueueServices rendering of the views for pages and thumbnails.
 *
 */
var LibService = (function () {
    function LibService() {
        this.renderingStates = {
            INITIAL: 0,
            RUNNING: 1,
            PAUSED: 2,
            FINISHED: 3
        };
        this.CLEANUP_TIMEOUT = 30000;
        this.pdfViewer = null;
        this.pdfThumbnailViewer = null;
        this.onIdle = null;
        this.highestPriorityPage = null;
        this.idleTimeout = null;
        this.printing = false;
        this.isThumbnailViewEnabled = false;
    }
    /**
     * @param {?} pdfViewer
     * @return {?}
     */
    LibService.prototype.setViewer = function (pdfViewer) {
        this.pdfViewer = pdfViewer;
    };
    /**
     * @param {?} pdfThumbnailViewer
     * @return {?}
     */
    LibService.prototype.setThumbnailViewer = function (pdfThumbnailViewer) {
        this.pdfThumbnailViewer = pdfThumbnailViewer;
    };
    /**
     * @param {?} view
     * @return {?}
     */
    LibService.prototype.isHighestPriority = function (view) {
        return this.highestPriorityPage === view.renderingId;
    };
    /**
     * @param {?} currentlyVisiblePages
     * @return {?}
     */
    LibService.prototype.renderHighestPriority = function (currentlyVisiblePages) {
        if (this.idleTimeout) {
            clearTimeout(this.idleTimeout);
            this.idleTimeout = null;
        }
        // Pages have a higher priority than thumbnails, so check them first.
        if (this.pdfViewer.forceRendering(currentlyVisiblePages)) {
            return;
        }
        // No pages needed rendering so check thumbnails.
        if (this.pdfThumbnailViewer && this.isThumbnailViewEnabled) {
            if (this.pdfThumbnailViewer.forceRendering()) {
                return;
            }
        }
        if (this.printing) {
            // If printing is currently ongoing do not reschedule cleanup.
            return;
        }
        if (this.onIdle) {
            this.idleTimeout = setTimeout(this.onIdle.bind(this), this.CLEANUP_TIMEOUT);
        }
    };
    /**
     * @param {?} visible
     * @param {?} views
     * @param {?} scrolledDown
     * @return {?}
     */
    LibService.prototype.getHighestPriority = function (visible, views, scrolledDown) {
        // The state has changed figure out which page has the highest priority to
        // render next (if any).
        // Priority:
        // 1 visible pages
        // 2 if last scrolled down page after the visible pages
        // 2 if last scrolled up page before the visible pages
        var /** @type {?} */ visibleViews = visible.views;
        var /** @type {?} */ numVisible = visibleViews.length;
        if (numVisible === 0) {
            return false;
        }
        for (var /** @type {?} */ i = 0; i < numVisible; ++i) {
            var /** @type {?} */ view = visibleViews[i].view;
            if (!this.isViewFinished(view)) {
                return view;
            }
        }
        // All the visible views have rendered, try to render next/previous pages.
        if (scrolledDown) {
            var /** @type {?} */ nextPageIndex = visible.last.id;
            // ID's start at 1 so no need to add 1.
            if (views[nextPageIndex] && !this.isViewFinished(views[nextPageIndex])) {
                return views[nextPageIndex];
            }
        }
        else {
            var /** @type {?} */ previousPageIndex = visible.first.id - 2;
            if (views[previousPageIndex] && !this.isViewFinished(views[previousPageIndex])) {
                return views[previousPageIndex];
            }
        }
        // Everything that needs to be rendered has been.
        return null;
    };
    /**
     * @param {?} view
     * @return {?}
     */
    LibService.prototype.isViewFinished = function (view) {
        return view.renderingState === this.renderingStates.FINISHED;
    };
    /**
     * Render a page or thumbnail view. This calls the appropriate function
     * based on the views state. If the view is already rendered it will return
     * false.
     * @param {?} view
     * @return {?}
     */
    LibService.prototype.renderView = function (view) {
        var /** @type {?} */ state = view.renderingState;
        switch (state) {
            case this.renderingStates.FINISHED:
                return false;
            case this.renderingStates.PAUSED:
                this.highestPriorityPage = view.renderingId;
                view.resume();
                break;
            case this.renderingStates.RUNNING:
                this.highestPriorityPage = view.renderingId;
                break;
            case this.renderingStates.INITIAL:
                this.highestPriorityPage = view.renderingId;
                var /** @type {?} */ continueRendering = function () {
                    this.renderHighestPriority();
                }.bind(this);
                view.draw().then(continueRendering, continueRendering);
                break;
            default:
                break;
        }
        return true;
    };
    return LibService;
}());
LibService.decorators = [
    { type: core.Injectable },
];
/**
 * @nocollapse
 */
LibService.ctorParameters = function () { return []; };

var LibComponent = (function () {
    /**
     * @param {?} renderingQueueServices
     */
    function LibComponent(renderingQueueServices) {
        this.renderingQueueServices = renderingQueueServices;
        this.showToolbar = true;
        this.currentScaleMode = 'auto';
        this.MAX_AUTO_SCALE = 0.75;
        this.DEFAULT_SCALE_DELTA = 1.1;
        this.MIN_SCALE = 0.25;
        this.MAX_SCALE = 10.0;
        //Custom Changes
        this.showContentChanged = new core.EventEmitter();
        this._showContent = false;
        this._canPrint = true;
        this.downloadContent = new core.EventEmitter();
    }
    Object.defineProperty(LibComponent.prototype, "showContent", {
        /**
         * @return {?}
         */
        get: function () {
            return this._showContent;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._showContent = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LibComponent.prototype, "canPrint", {
        /**
         * @return {?}
         */
        get: function () {
            return this._canPrint;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._canPrint = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    LibComponent.prototype.closePdf = function () {
        this._showContent = false;
        this.showContentChanged.emit(false);
    };
    /**
     * @return {?}
     */
    LibComponent.prototype.printPdf = function () {
        var /** @type {?} */ iframe = document.createElement('iframe');
        iframe.style.display = 'none';
        iframe.src = this.urlFile;
        document.body.appendChild(iframe);
        //iframe.contentWindow.print();
    };
    /**
     * @return {?}
     */
    LibComponent.prototype.downloadPdf = function () {
        this.downloadContent.emit(true);
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    LibComponent.prototype.ngOnChanges = function (changes) {
        var _this = this;
        if (!this.urlFile && !this.blobFile) {
            throw new Error('Attribute urlFile or blobFile is required');
        }
        if (this.urlFile) {
            return new Promise(function (resolve, reject) {
                _this.executePdf(_this.urlFile, resolve, reject);
            });
        }
        else {
            return new Promise(function (resolve, reject) {
                var /** @type {?} */ reader = new FileReader();
                reader.onload = function () {
                    _this.executePdf(reader.result, resolve, reject);
                };
                reader.readAsArrayBuffer(_this.blobFile);
            });
        }
    };
    /**
     * @param {?} src
     * @param {?} resolve
     * @param {?} reject
     * @return {?}
     */
    LibComponent.prototype.executePdf = function (src, resolve, reject) {
        var _this = this;
        var /** @type {?} */ loadingTask = this.getPDFJS().getDocument(src);
        loadingTask.onProgress = function (progressData) {
            var /** @type {?} */ level = progressData.loaded / progressData.total;
            _this.laodingPercent = Math.round(level * 100);
        };
        loadingTask.then(function (pdfDocument) {
            _this.currentPdfDocument = pdfDocument;
            _this.totalPages = pdfDocument.numPages;
            _this.page = 1;
            _this.displayPage = 1;
            _this.initPDFViewer(_this.currentPdfDocument);
            _this.currentPdfDocument.getPage(1).then(function () {
                _this.scalePage('auto');
                resolve();
            }, function (error) {
                reject(error);
            });
        }, function (error) {
            reject(error);
        });
    };
    /**
     * return the PDFJS global object (exist to facilitate the mock of PDFJS in the test)
     *
     * @return {?}
     */
    LibComponent.prototype.getPDFJS = function () {
        return PDFJS;
    };
    /**
     * @param {?} pdfDocument
     * @return {?}
     */
    LibComponent.prototype.initPDFViewer = function (pdfDocument) {
        var _this = this;
        PDFJS.verbosity = 1;
        PDFJS.disableWorker = false;
        var /** @type {?} */ documentContainer = document.getElementById('viewer-pdf-container');
        var /** @type {?} */ viewer = document.getElementById('viewer-viewerPdf');
        window.document.addEventListener('scroll', function (event) {
            _this.watchScroll(event.target);
        }, true);
        this.pdfViewer = new PDFJS.PDFViewer({
            container: documentContainer,
            viewer: viewer,
            renderingQueue: this.renderingQueueServices
        });
        this.renderingQueueServices.setViewer(this.pdfViewer);
        this.pdfViewer.setDocument(pdfDocument);
    };
    /**
     * Method to scale the page current support implementation
     *
     * @param {?} scaleMode
     * @return {?}
     */
    LibComponent.prototype.scalePage = function (scaleMode) {
        this.currentScaleMode = scaleMode;
        if (this.pdfViewer) {
            var /** @type {?} */ viewerContainer = document.getElementById('viewer-main-container');
            var /** @type {?} */ documentContainer = document.getElementById('viewer-pdf-container');
            var /** @type {?} */ widthContainer = void 0;
            var /** @type {?} */ heigthContainer = void 0;
            if (viewerContainer && viewerContainer.clientWidth <= documentContainer.clientWidth) {
                widthContainer = viewerContainer.clientWidth;
                heigthContainer = viewerContainer.clientHeight;
            }
            else {
                widthContainer = documentContainer.clientWidth;
                heigthContainer = documentContainer.clientHeight;
            }
            var /** @type {?} */ currentPage = this.pdfViewer._pages[this.pdfViewer._currentPageNumber - 1];
            var /** @type {?} */ padding = 20;
            var /** @type {?} */ pageWidthScale = (widthContainer - padding) / currentPage.width * currentPage.scale;
            var /** @type {?} */ pageHeightScale = (heigthContainer - padding) / currentPage.width * currentPage.scale;
            var /** @type {?} */ scale = void 0;
            switch (this.currentScaleMode) {
                case 'page-actual':
                    scale = 1;
                    break;
                case 'page-width':
                    scale = pageWidthScale;
                    break;
                case 'page-height':
                    scale = pageHeightScale;
                    break;
                case 'page-fit':
                    scale = Math.min(pageWidthScale, pageHeightScale);
                    break;
                case 'auto':
                    var /** @type {?} */ horizontalScale = void 0;
                    if (this.isLandscape) {
                        horizontalScale = Math.min(pageHeightScale, pageWidthScale);
                    }
                    else {
                        horizontalScale = pageWidthScale;
                    }
                    scale = Math.max(this.MAX_AUTO_SCALE, horizontalScale);
                    break;
                default:
                    //this.logService.error('pdfViewSetScale: \'' + scaleMode + '\' is an unknown zoom value.');
                    return;
            }
            this.setScaleUpdatePages(scale);
        }
    };
    /**
     * Update all the pages with the newScale scale
     *
     * @param {?} newScale
     * @return {?}
     */
    LibComponent.prototype.setScaleUpdatePages = function (newScale) {
        if (!this.isSameScale(this.currentScale, newScale)) {
            this.currentScale = newScale;
            this.pdfViewer._pages.forEach(function (currentPage) {
                currentPage.update(newScale);
            });
            this.pdfViewer.update();
        }
    };
    /**
     * method to check if the request scale of the page is the same for avoid unuseful re-rendering
     *
     * @param {?} oldScale - old scale page
     * @param {?} newScale - new scale page
     *
     * @return {?} boolean
     */
    LibComponent.prototype.isSameScale = function (oldScale, newScale) {
        return (newScale === oldScale);
    };
    /**
     * method to check if is a land scape view
     *
     * @param {?} width
     * @param {?} height
     *
     * @return {?} boolean
     */
    LibComponent.prototype.isLandscape = function (width, height) {
        return (width > height);
    };
    /**
     * Method triggered when the page is resized
     * @return {?}
     */
    LibComponent.prototype.onResize = function () {
        this.scalePage(this.currentScaleMode);
    };
    /**
     * toggle the fit page pdf
     * @return {?}
     */
    LibComponent.prototype.pageFit = function () {
        if (this.currentScaleMode !== 'page-fit') {
            this.scalePage('page-fit');
        }
        else {
            this.scalePage('auto');
        }
    };
    /**
     * zoom in page pdf
     *
     * @param {?} ticks
     * @return {?}
     */
    LibComponent.prototype.zoomIn = function (ticks) {
        var /** @type {?} */ newScale = this.currentScale;
        do {
            newScale = (newScale * this.DEFAULT_SCALE_DELTA).toFixed(2);
            newScale = Math.ceil(newScale * 10) / 10;
            newScale = Math.min(this.MAX_SCALE, newScale);
        } while (--ticks > 0 && newScale < this.MAX_SCALE);
        this.currentScaleMode = 'auto';
        this.setScaleUpdatePages(newScale);
    };
    /**
     * zoom out page pdf
     *
     * @param {?} ticks
     * @return {?}
     */
    LibComponent.prototype.zoomOut = function (ticks) {
        var /** @type {?} */ newScale = this.currentScale;
        do {
            newScale = (newScale / this.DEFAULT_SCALE_DELTA).toFixed(2);
            newScale = Math.floor(newScale * 10) / 10;
            newScale = Math.max(this.MIN_SCALE, newScale);
        } while (--ticks > 0 && newScale > this.MIN_SCALE);
        this.currentScaleMode = 'auto';
        this.setScaleUpdatePages(newScale);
    };
    /**
     * load the previous page
     * @return {?}
     */
    LibComponent.prototype.previousPage = function () {
        if (this.pdfViewer && this.page > 1) {
            this.page--;
            this.displayPage = this.page;
            this.pdfViewer.currentPageNumber = this.page;
        }
    };
    /**
     * load the next page
     * @return {?}
     */
    LibComponent.prototype.nextPage = function () {
        if (this.pdfViewer && this.page < this.totalPages) {
            this.page++;
            this.displayPage = this.page;
            this.pdfViewer.currentPageNumber = this.page;
        }
    };
    /**
     * load the page in input
     *
     * @param {?} page
     * @return {?}
     */
    LibComponent.prototype.inputPage = function (page) {
        var /** @type {?} */ pageInput = parseInt(page, 10);
        if (!isNaN(pageInput) && pageInput > 0 && pageInput <= this.totalPages) {
            this.page = pageInput;
            this.displayPage = this.page;
            this.pdfViewer.currentPageNumber = this.page;
        }
        else {
            this.displayPage = this.page;
        }
    };
    /**
     * Litener Scroll Event
     *
     * @param {?} target
     * @return {?}
     */
    LibComponent.prototype.watchScroll = function (target) {
        var /** @type {?} */ outputPage = this.getVisibleElement(target);
        if (outputPage) {
            this.page = outputPage.id;
            this.displayPage = this.page;
        }
    };
    /**
     * find out what elements are visible within a scroll pane
     *
     * @param {?} target
     * @return {?}
     */
    LibComponent.prototype.getVisibleElement = function (target) {
        var _this = this;
        return this.pdfViewer._pages.find(function (page) {
            return _this.isOnScreen(page, target);
        });
    };
    /**
     * check if a page is visible
     *
     * @param {?} page
     * @param {?} target
     * @return {?}
     */
    LibComponent.prototype.isOnScreen = function (page, target) {
        var /** @type {?} */ viewport = {};
        viewport.top = target.scrollTop;
        viewport.bottom = viewport.top + target.scrollHeight;
        var /** @type {?} */ bounds = {};
        bounds.top = page.div.offsetTop;
        bounds.bottom = bounds.top + page.viewport.height;
        return ((bounds.top <= viewport.bottom) && (bounds.bottom >= viewport.top));
    };
    /**
     * Litener Keyboard Event
     * @param {?} event
     * @return {?}
     */
    LibComponent.prototype.handleKeyboardEvent = function (event) {
        var /** @type {?} */ key = event.keyCode;
        if (key === 39) {
            this.nextPage();
        }
        else if (key === 37) {
            this.previousPage();
        }
    };
    return LibComponent;
}());
LibComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'pdf-viewer',
                template: "\n\n      <div class=\"mainDiv\" *ngIf=\"_showContent\">\n        <!-- Start Pdf Canvas -->\n        <div id=\"viewer-pdf-container\" class=\"viewer-pdf-container\" (keypress)=eventHandler() (window:resize)=\"onResize($event)\">\n            <div id=\"viewer-viewerPdf\" class=\"pdfViewer\">\n                <div id=\"loader-container\" class=\"loader-container\">\n                    <div class=\"loader-item\">\n                        <div id=\"loader-spin\" class=\"mdl-progress mdl-js-progress mdl-progress__indeterminate\"></div>\n                        <div id=\"loader-text\" class=\"loader-text\">Loading <span>{{nameFile}}</span> {{laodingPercent}}%</div>\n                    </div>\n                </div>\n            </div>\n        </div>\n        <!-- End Pdf Canvas -->\n        <!-- Close Section -->\n        <div class=\"pdf-btn-row\">\n\n            <div id=\"viewer-toolbar-view-options\">\n                <button (click)=\"downloadPdf()\" class=\"close-pdf\" *ngIf=\"_canPrint\">\n                    <!--<i class=\"icon material-icons\" id=\"viewer-close-button\">&#xE2C4;</i>-->\n                    <i class=\"material-icons\">&#xE8AD;</i>\n                </button>\n                <button class=\"close-pdf\" (click)=\"closePdf()\">\n                    <i class=\"icon material-icons\" id=\"viewer-close-button\">close</i>\n                </button>\n          \n            </div>\n            <!-- End Close Section -->\n            <!-- Pagination toolbar start -->\n            <div *ngIf=\"showToolbar\" id=\"viewer-toolbar-pagination\" class=\"viewer-toolbar-pagination mdl-cell--hide-tablet mdl-cell--hide-phone\">\n                <div id=\"viewer-previous-page-button\" aria-label=\"arrow left\" class=\"button-page left\" (click)=\"previousPage()\">\n                    <i class=\"icon material-icons\">keyboard_arrow_left</i>\n                </div>\n\n                <div class=\"viewer-page-counter left\">\n                    <input id=\"viewer-pagenumber-input\" #page\n                           (keyup.enter)=\"inputPage(page.value)\" class=\"viewer-pagenumber-input left\" type=\"text\" pattern=\"-?[0-9]*(\\.[0-9]+)?\" value=\"{{displayPage}}\">\n                    <div id=\"viewer-total-pages\" class=\"left viewer-total-pages\">/ {{totalPages}}</div>\n                </div>\n\n                <div id=\"viewer-next-page-button\" aria-label=\"arrow right\" class=\"button-page left\" (click)=\"nextPage()\">\n                    <i class=\"icon material-icons\">keyboard_arrow_right</i>\n                </div>\n            </div>\n            <!-- Pagination toolbar end -->\n            <!-- Command toolbar start -->\n            <div *ngIf=\"showToolbar\" id=\"viewer-toolbar-command\" class=\"viewer-toolbar-command\">\n                <div id=\"viewer-scale-page-button\" aria-label=\"zoom out map\" class=\"button-page left\" (click)=\"pageFit()\">\n                    <i class=\"icon material-icons\">zoom_out_map</i>\n                </div>\n                <div id=\"viewer-zoom-in-button\" aria-label=\"zoom in\" class=\"button-page left\" (click)=\"zoomIn()\">\n                    <i class=\"icon material-icons\">zoom_in</i>\n                </div>\n                <div id=\"viewer-zoom-out-button\" aria-label=\"zoom out\" class=\"button-page left\" (click)=\"zoomOut()\">\n                    <i class=\"icon material-icons\">zoom_out</i>\n                </div>\n            </div>\n            <!-- Command toolbar end -->\n\n        </div>\n      </div>\n    ",
                styles: ["\n      .loader-container{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-flex-direction:row;-moz-box-flex-direction:row;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;height:100%}.loader-item{margin:auto;max-height:100px;max-width:300px}.loader-text{white-space:nowrap;text-align:center;position:relative;color:#fff}.left{float:left}.pdfViewer-container{position:fixed;top:0;left:0;width:100%;height:100%;z-index:1}.pdf-btn-row{position:fixed;width:100%;top:20px;left:0;z-index:2}.close-pdf{background:none;color:#fff;border:0}.viewer-toolbar-pagination{padding-top:4px;top:80px;right:35px;width:auto;position:absolute;border-radius:10px;background:#3e3e3e;color:#fff}.mainDiv{color:rgba(0,0,0,.87)}#viewer-toolbar-view-options{padding-top:3px 5px;top:30px;right:35px;width:auto;position:absolute;border-radius:5px;background:#3e3e3e}.viewer-toolbar-command{height:30px;padding-top:4px;top:80px;left:35px;width:auto;position:absolute;border-radius:10px;background:#3e3e3e;color:#fff}.viewer-pagenumber-input{border:none;display:block;background:0 0;width:33px}.viewer-pagenumber-input,.viewer-total-pages{font-size:16px;padding:4px 0;text-align:right;color:inherit;margin-right:4px;height:20px}.viewer-total-pages{border:medium none;display:-webkit-box;display:-ms-flexbox;display:flex;background:transparent none repeat scroll 0 0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.viewer-page-counter{margin-right:20px}.button-page{margin-right:4px;height:24px;width:24px;margin-left:4px;cursor:pointer}.button-page:hover{cursor:pointer;background:grey;border-radius:24px}:host>>>.textLayer{position:absolute;left:0;top:0;right:0;bottom:0;overflow:hidden;opacity:.2;line-height:1}:host>>>.textLayer>div{color:transparent;position:absolute;white-space:pre;cursor:text;-webkit-transform-origin:0 0;transform-origin:0 0}:host>>>.textLayer .highlight{margin:-1px;padding:1px;background-color:#b400aa;border-radius:4px}:host>>>.textLayer .highlight.begin{border-radius:4px 0 0 4px}:host>>>.textLayer .highlight.end{border-radius:0 4px 4px 0}:host>>>.textLayer .highlight.middle{border-radius:0}:host>>>.textLayer .highlight.selected{background-color:#006400}:host>>>.textLayer ::selection{background:#00f}:host>>>.textLayer ::-moz-selection{background:#00f}:host>>>.textLayer .endOfContent{display:block;position:absolute;left:0;top:100%;right:0;bottom:0;z-index:-1;cursor:default;-webkit-user-select:none;-ms-user-select:none;-moz-user-select:none}:host>>>.textLayer .endOfContent.active{top:0}:host>>>.annotationLayer section{position:absolute}:host>>>.annotationLayer .linkAnnotation>a{position:absolute;font-size:1em;top:0;left:0;width:100%;height:100%;background:url(\"data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7\") 0 0 repeat}:host>>>.annotationLayer .linkAnnotation>a:hover{opacity:.2;background:#ff0;-webkit-box-shadow:0 2px 10px #ff0;box-shadow:0 2px 10px #ff0}:host>>>.annotationLayer .textAnnotation img{position:absolute;cursor:pointer}:host>>>.annotationLayer .popupWrapper{position:absolute;width:20em}:host>>>.annotationLayer .popup{position:absolute;z-index:200;max-width:20em;background-color:#ff9;-webkit-box-shadow:0 2px 5px #333;box-shadow:0 2px 5px #333;border-radius:2px;padding:.6em;margin-left:5px;cursor:pointer;word-wrap:break-word}:host>>>.annotationLayer .popup h1{font-size:1em;border-bottom:1px solid #000;padding-bottom:.2em}:host>>>.annotationLayer .popup p{padding-top:.2em}.annotationLayer .fileAttachmentAnnotation,.annotationLayer .squigglyAnnotation,.annotationLayer .strikeoutAnnotation,.annotationLayer .underlineAnnotation,:host>>>.annotationLayer .highlightAnnotation{cursor:pointer}:host>>>.pdfViewer .canvasWrapper{overflow:hidden}:host>>>.pdfViewer .page{direction:ltr;width:816px;height:1056px;margin:1px auto -8px;position:relative;overflow:visible;border:9px solid transparent;background-clip:content-box;background-color:#fff}:host>>>.pdfViewer.removePageBorders .page{margin:0 auto 10px;border:none}:host>>>.pdfViewer .page canvas{margin:0;display:block}:host>>>.pdfViewer .page .loadingIcon{position:absolute;display:block;left:0;top:0;right:0;bottom:0}:host>>>.loadingIcon{width:100px;height:100px;left:50%!important;top:50%!important;margin-top:-50px;margin-left:-50px;font-size:5px;text-indent:-9999em;border-top:1.1em solid rgba(3,0,2,.2);border-right:1.1em solid rgba(3,0,2,.2);border-bottom:1.1em solid rgba(3,0,2,.2);border-left:1.1em solid #030002;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-animation:a 1.1s infinite linear;animation:a 1.1s infinite linear}:host>>>.loadingIcon,:host>>>.loadingIcon:after{border-radius:50%}@-webkit-keyframes a{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}@keyframes a{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}:host>>>*{padding:0;margin:0}:host>>>html{height:100%;width:100%;font-size:10px}:host>>>body{height:100%;width:100%;background-color:#404040}:host>>>body,button,input,select{font:message-box;outline:none}:host>>>.hidden,:host>>>[hidden]{display:none!important}#viewer-pdf-container{overflow:auto;-webkit-overflow-scrolling:touch;position:absolute;top:0;right:0;bottom:0;left:0;outline:none;background:#555;z-index:9999}html[dir=ltr] #viewer-pdf-container{-webkit-box-shadow:inset 1px 0 0 hsla(0,0%,100%,.05);box-shadow:inset 1px 0 0 hsla(0,0%,100%,.05)}html[dir=rtl] #viewer-pdf-container{-webkit-box-shadow:inset -1px 0 0 hsla(0,0%,100%,.05);box-shadow:inset -1px 0 0 hsla(0,0%,100%,.05)}\n    "],
                providers: [LibService]
            },] },
];
/**
 * @nocollapse
 */
LibComponent.ctorParameters = function () { return [
    { type: LibService, },
]; };
LibComponent.propDecorators = {
    'urlFile': [{ type: core.Input },],
    'blobFile': [{ type: core.Input },],
    'nameFile': [{ type: core.Input },],
    'showToolbar': [{ type: core.Input },],
    'showContentChanged': [{ type: core.Output },],
    'downloadContent': [{ type: core.Output },],
    'showContent': [{ type: core.Input },],
    'canPrint': [{ type: core.Input },],
    'handleKeyboardEvent': [{ type: core.HostListener, args: ['document:keydown', ['$event'],] },],
};

var PdfViewerModule = (function () {
    function PdfViewerModule() {
    }
    /**
     * @return {?}
     */
    PdfViewerModule.forRoot = function () {
        return {
            ngModule: PdfViewerModule,
            providers: [LibService]
        };
    };
    return PdfViewerModule;
}());
PdfViewerModule.decorators = [
    { type: core.NgModule, args: [{
                imports: [
                    common.CommonModule
                ],
                exports: [LibComponent],
                declarations: [LibComponent]
            },] },
];
/**
 * @nocollapse
 */
PdfViewerModule.ctorParameters = function () { return []; };

//export * from './module/pdf-viewer/pdf-viewer.module';

/**
 * Generated bundle index. Do not edit.
 */

exports.LibComponent = LibComponent;
exports.LibService = LibService;
exports.PdfViewerModule = PdfViewerModule;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-pdf-viewer.umd.js.map
