import { EventEmitter } from '@angular/core';
import { LibService } from '../service/lib.service';
import 'pdfjs-dist/build/pdf.combined';
import 'pdfjs-dist/web/pdf_viewer';
export declare class LibComponent {
    private renderingQueueServices;
    urlFile: string;
    blobFile: Blob;
    nameFile: string;
    showToolbar: boolean;
    currentPdfDocument: any;
    page: number;
    displayPage: number;
    totalPages: number;
    laodingPercent: number;
    pdfViewer: any;
    currentScaleMode: string;
    currentScale: number;
    MAX_AUTO_SCALE: number;
    DEFAULT_SCALE_DELTA: number;
    MIN_SCALE: number;
    MAX_SCALE: number;
    showContentChanged: EventEmitter<boolean>;
    _showContent: boolean;
    private _canPrint;
    downloadContent: EventEmitter<boolean>;
    showContent: boolean;
    canPrint: boolean;
    closePdf(): void;
    printPdf(): void;
    downloadPdf(): void;
    constructor(renderingQueueServices: LibService);
    ngOnChanges(changes: any): Promise<{}>;
    executePdf(src: any, resolve: any, reject: any): void;
    /**
     * return the PDFJS global object (exist to facilitate the mock of PDFJS in the test)
     *
     */
    getPDFJS(): any;
    initPDFViewer(pdfDocument: any): void;
    /**
     * Method to scale the page current support implementation
     *
     */
    scalePage(scaleMode: any): void;
    /**
     * Update all the pages with the newScale scale
     *
     */
    setScaleUpdatePages(newScale: number): void;
    /**
     * method to check if the request scale of the page is the same for avoid unuseful re-rendering
     *
     * @param  oldScale - old scale page
     * @param  newScale - new scale page
     *
     * @returns boolean
     */
    isSameScale(oldScale: number, newScale: number): boolean;
    /**
     * method to check if is a land scape view
     *
     * @param  width
     * @param  height
     *
     * @returns boolean
     */
    isLandscape(width: number, height: number): boolean;
    /**
     * Method triggered when the page is resized
     */
    onResize(): void;
    /**
     * toggle the fit page pdf
     */
    pageFit(): void;
    /**
     * zoom in page pdf
     *
     * @param  ticks
     */
    zoomIn(ticks: number): void;
    /**
     * zoom out page pdf
     *
     * @param  ticks
     */
    zoomOut(ticks: number): void;
    /**
     * load the previous page
     */
    previousPage(): void;
    /**
     * load the next page
     */
    nextPage(): void;
    /**
     * load the page in input
     *
     * @param string page - page to load
     */
    inputPage(page: string): void;
    /**
     * Litener Scroll Event
     *
     * @param any target
     */
    watchScroll(target: any): void;
    /**
     * find out what elements are visible within a scroll pane
     *
     */
    getVisibleElement(target: any): any;
    /**
     * check if a page is visible
     *
     */
    isOnScreen(page: any, target: any): boolean;
    /**
     * Litener Keyboard Event
     */
    handleKeyboardEvent(event: KeyboardEvent): void;
}
